==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/EmailTemplateResponseLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailTemplateResponseLinks
 */
@JsonPropertyOrder({ EmailTemplateResponseLinks.JSON_PROPERTY_SELF, EmailTemplateResponseLinks.JSON_PROPERTY_SETTINGS,
        EmailTemplateResponseLinks.JSON_PROPERTY_DEFAULT_CONTENT,
        EmailTemplateResponseLinks.JSON_PROPERTY_CUSTOMIZATIONS, EmailTemplateResponseLinks.JSON_PROPERTY_TEST })
@JsonTypeName("EmailTemplateResponse__links")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailTemplateResponseLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_SETTINGS = "settings";
    private HrefObject settings;

    public static final String JSON_PROPERTY_DEFAULT_CONTENT = "defaultContent";
    private HrefObject defaultContent;

    public static final String JSON_PROPERTY_CUSTOMIZATIONS = "customizations";
    private HrefObject customizations;

    public static final String JSON_PROPERTY_TEST = "test";
    private HrefObject test;

    public EmailTemplateResponseLinks() {
    }

    public EmailTemplateResponseLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public EmailTemplateResponseLinks settings(HrefObject settings) {

        this.settings = settings;
        return this;
    }

    /**
     * Get settings
     *
     * @return settings
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getSettings() {
        return settings;
    }

    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSettings(HrefObject settings) {
        this.settings = settings;
    }

    public EmailTemplateResponseLinks defaultContent(HrefObject defaultContent) {

        this.defaultContent = defaultContent;
        return this;
    }

    /**
     * Get defaultContent
     *
     * @return defaultContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDefaultContent() {
        return defaultContent;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefaultContent(HrefObject defaultContent) {
        this.defaultContent = defaultContent;
    }

    public EmailTemplateResponseLinks customizations(HrefObject customizations) {

        this.customizations = customizations;
        return this;
    }

    /**
     * Get customizations
     *
     * @return customizations
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZATIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getCustomizations() {
        return customizations;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZATIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizations(HrefObject customizations) {
        this.customizations = customizations;
    }

    public EmailTemplateResponseLinks test(HrefObject test) {

        this.test = test;
        return this;
    }

    /**
     * Get test
     *
     * @return test
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTest() {
        return test;
    }

    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTest(HrefObject test) {
        this.test = test;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailTemplateResponseLinks emailTemplateResponseLinks = (EmailTemplateResponseLinks) o;
        return Objects.equals(this.self, emailTemplateResponseLinks.self)
                && Objects.equals(this.settings, emailTemplateResponseLinks.settings)
                && Objects.equals(this.defaultContent, emailTemplateResponseLinks.defaultContent)
                && Objects.equals(this.customizations, emailTemplateResponseLinks.customizations)
                && Objects.equals(this.test, emailTemplateResponseLinks.test);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, settings, defaultContent, customizations, test);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailTemplateResponseLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    settings: ").append(toIndentedString(settings)).append("\n");
        sb.append("    defaultContent: ").append(toIndentedString(defaultContent)).append("\n");
        sb.append("    customizations: ").append(toIndentedString(customizations)).append("\n");
        sb.append("    test: ").append(toIndentedString(test)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/EmailTemplateResponseLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailTemplateResponseLinks
 */
@JsonPropertyOrder({ EmailTemplateResponseLinks.JSON_PROPERTY_SELF, EmailTemplateResponseLinks.JSON_PROPERTY_SETTINGS,
        EmailTemplateResponseLinks.JSON_PROPERTY_DEFAULT_CONTENT,
        EmailTemplateResponseLinks.JSON_PROPERTY_CUSTOMIZATIONS, EmailTemplateResponseLinks.JSON_PROPERTY_TEST })
@JsonTypeName("EmailTemplateResponse__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailTemplateResponseLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_SETTINGS = "settings";
    private HrefObject settings;

    public static final String JSON_PROPERTY_DEFAULT_CONTENT = "defaultContent";
    private HrefObject defaultContent;

    public static final String JSON_PROPERTY_CUSTOMIZATIONS = "customizations";
    private HrefObject customizations;

    public static final String JSON_PROPERTY_TEST = "test";
    private HrefObject test;

    public EmailTemplateResponseLinks() {
    }

    public EmailTemplateResponseLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public EmailTemplateResponseLinks settings(HrefObject settings) {

        this.settings = settings;
        return this;
    }

    /**
     * Get settings
     *
     * @return settings
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getSettings() {
        return settings;
    }

    @JsonProperty(JSON_PROPERTY_SETTINGS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSettings(HrefObject settings) {
        this.settings = settings;
    }

    public EmailTemplateResponseLinks defaultContent(HrefObject defaultContent) {

        this.defaultContent = defaultContent;
        return this;
    }

    /**
     * Get defaultContent
     *
     * @return defaultContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getDefaultContent() {
        return defaultContent;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefaultContent(HrefObject defaultContent) {
        this.defaultContent = defaultContent;
    }

    public EmailTemplateResponseLinks customizations(HrefObject customizations) {

        this.customizations = customizations;
        return this;
    }

    /**
     * Get customizations
     *
     * @return customizations
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZATIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getCustomizations() {
        return customizations;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZATIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizations(HrefObject customizations) {
        this.customizations = customizations;
    }

    public EmailTemplateResponseLinks test(HrefObject test) {

        this.test = test;
        return this;
    }

    /**
     * Get test
     *
     * @return test
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTest() {
        return test;
    }

    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTest(HrefObject test) {
        this.test = test;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailTemplateResponseLinks emailTemplateResponseLinks = (EmailTemplateResponseLinks) o;
        return Objects.equals(this.self, emailTemplateResponseLinks.self)
                && Objects.equals(this.settings, emailTemplateResponseLinks.settings)
                && Objects.equals(this.defaultContent, emailTemplateResponseLinks.defaultContent)
                && Objects.equals(this.customizations, emailTemplateResponseLinks.customizations)
                && Objects.equals(this.test, emailTemplateResponseLinks.test);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, settings, defaultContent, customizations, test);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailTemplateResponseLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    settings: ").append(toIndentedString(settings)).append("\n");
        sb.append("    defaultContent: ").append(toIndentedString(defaultContent)).append("\n");
        sb.append("    customizations: ").append(toIndentedString(customizations)).append("\n");
        sb.append("    test: ").append(toIndentedString(test)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
